@@ -274,7 +274,7 @@ panel_set_bg(MBPanel *panel, int bg_type, char *bg_spec)
     case BG_PIXMAP:
       if (bg_spec[0] != '/' && panel->theme_path != NULL)
 	{
-	  tmp_path = alloca( sizeof(char) * (strlen(panel->theme_path) + strlen(bg_spec)));
+	  tmp_path = alloca( sizeof(char) * (strlen(panel->theme_path) + strlen(bg_spec) + 2));
 	  sprintf(tmp_path, "%s/%s", panel->theme_path, bg_spec);
 	}
       else tmp_path = bg_spec;
@@ -663,7 +663,7 @@ panel_set_theme_from_root_prop(MBPanel *panel)
 void 
 panel_usage(char *bin_name)
 {
-  fprintf(stderr, "%s usage: %s [Options...]\n"
+  fprintf(stderr, "%s (%s) usage: %s [Options...]\n"
 	  "Where options are;\n"
           "-display, -d         <X11 Display name>\n"
           "-geometry, -g        Use --size / --orientation instead.\n"
@@ -687,7 +687,7 @@ panel_usage(char *bin_name)
 	  "--bgtrans,  -bt      <'yes'|transparency percentage>\n"
 	  "*NOTE* setting the background here will disable the effect\n"
 	  "       of any external theme changes. \n"
-	  , bin_name, bin_name);
+	  , bin_name, VERSION, bin_name);
   exit(1);
 }
 
@@ -1036,6 +1036,13 @@ panel_main(MBPanel *panel)
 	  mb_menu_handle_xevent(panel->mbmenu, &an_event);
 	  switch (an_event.type)
 	    {
+	    case SelectionClear:
+	      if (an_event.xselectionclear.selection == panel->atoms[ATOM_SYSTEM_TRAY])
+		{
+		  fprintf(stderr, "matchbox-panel: Another system tray has started and taken tray ID. Exiting.\n");
+		  exit(-1);
+		}
+	      break;
 	    case ButtonPress:
 	      panel_handle_button_event(panel, &an_event.xbutton);
 	      break;
